@@ -16,17 +16,21 @@ function squirrelmail_plugin_init_templates () {
         'plugin_templates_optpage_register_block_stub';
 }
 
+/** @ignore */
+if (!defined('SM_PATH')) 
+    define('SM_PATH', '../');
+
 function templates_version() {
-	return '1.0';
+	return '1.1';
 }
 
 function plugin_templates_compose_button_row_stub() {
-    include_once('functions.php');
+    include_once(SM_PATH . 'plugins/templates/functions.php');
     plugin_templates_compose_button_row();
 }
 
 function plugin_templates_optpage_register_block_stub() {
-    include_once('functions.php');
+    include_once(SM_PATH . 'plugins/templates/functions.php');
     plugin_templates_optpage_register_block();
 }
 
